Polynomials
===========

.. https://numpy.org/doc/stable/reference/routines.polynomials.html

Polynomial Package
------------------

Polynomial Module
~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.polynomial.polynomial.polyvander
   cupy.polynomial.polynomial.polycompanion


Polyutils
~~~~~~~~~

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.polynomial.polyutils.as_series
   cupy.polynomial.polyutils.trimseq


Poly1d
------

Basics
~~~~~~

.. autosummary::
   :toctree: generated/
   :nosignatures:

    cupy.poly1d
